==> doteki-0.0.1.tar.gz: doteki-0.0.1/README.md <==
<p align="center">
    <a href="https://doteki.org/">
        <img src="https://raw.githubusercontent.com/welpo/doteki/main/website/static/img/doteki-logo-text.png" width="300" alt="doteki logo: a river passing through a bamboo forest">
    </a>
    <br>
    <a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/code_style-black-000000?style=flat-square&labelColor=202b2d&color=black" alt="Code style: black"></a>
    <a href="https://pypi.org/project/doteki/"><img src="https://img.shields.io/pypi/v/doteki?style=flat-square&labelColor=202b2d&color=5E936C" alt="PyPI version"></a>
    <a href="https://codecov.io/gh/welpo/doteki">
        <img src="https://img.shields.io/codecov/c/github/welpo/doteki?style=flat-square&logo=codecov&logoColor=white&labelColor=202b2d&color=5E936" alt="Codecov"></a>
    <br>
    <a href="https://doteki.org/docs">
        <img src="https://img.shields.io/website?url=https%3A%2F%2Fdoteki.org&style=flat-square&label=docs&labelColor=202b2d&color=5E936C" alt="Documentation"></a>
    <a href="https://github.com/welpo/doteki/blob/main/COPYING">
        <img src="https://img.shields.io/github/license/welpo/doteki?style=flat-square&labelColor=5E936C&color=202b2d" alt="License"></a>
    <a href="https://doteki.org">
        <img src="https://img.shields.io/badge/powered_by-d%C5%8Dteki-0?style=flat-square&labelColor=202b2d&color=5E936C" alt="Powered by dōteki"></a>
</p>

<h4 align="center">
  <a href="https://doteki.org/docs">Documentation</a> |
  <a href="https://doteki.org">Website</a>
</h4>

**dōteki** makes it easy to add dynamic content to your GitHub profile leveraging customizable plugins managed through an intuitive TOML configuration file.

> dōteki (動的): dynamic.

## ✨ Main features

- **Easy to set up**: Uses a single TOML [configuration](https://doteki.org/docs/configuration) file and markers on your README.
- **Plugin system**: Extend functionality with a variety of [plugins](https://doteki.org/docs/category/plugins). Can't find what you need? [Create your own!](https://doteki.org/docs/developer-guide/plugin-standard)
- **Easy to automate**: Automatically update your profile with fresh content using the [GitHub Action](https://github.com/welpo/doteki-action).

## 📝 Documentation

Learn how to use **dōteki** from the [documentation](https://doteki.org/docs).

- [Initial setup](https://doteki.org/docs#initial-setup)
- [Configuration](https://doteki.org/docs/configuration)
- [Installation](https://doteki.org/docs/installation)
- [Plugins](https://doteki.org/docs/category/plugins)

## 👥 Contributing

Please do! Contributions are always welcome. We appreciate improvements to the documentation, development of new plugins, code cleanup, resolving issues, requesting or developing new functionality…

Take a look at our [Contributing Guidelines](/CONTRIBUTING.md) for more information on how to get started.

## 📄 License

This project is licensed under the GNU GPLv3 License or any later version.

==> doteki-0.0.2.tar.gz: doteki-0.0.2/README.md <==
<p align="center">
    <a href="https://doteki.org/">
        <img src="https://raw.githubusercontent.com/welpo/doteki/main/website/static/img/doteki-logo-text.png" width="300" alt="doteki logo: a river passing through a bamboo forest">
    </a>
    <br>
    <a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/code_style-black-000000?style=flat-square&labelColor=202b2d&color=black" alt="Code style: black"></a>
    <a href="https://pypi.org/project/doteki/"><img src="https://img.shields.io/pypi/v/doteki?style=flat-square&labelColor=202b2d&color=5E936C" alt="PyPI version"></a>
    <a href="https://codecov.io/gh/welpo/doteki">
        <img src="https://img.shields.io/codecov/c/gh/welpo/doteki?style=flat-square&logo=codecov&logoColor=white&labelColor=202b2d&color=5E936C" alt="Codecov"></a>
    <br>
    <a href="https://doteki.org/docs">
        <img src="https://img.shields.io/website?url=https%3A%2F%2Fdoteki.org&style=flat-square&label=docs&labelColor=202b2d&color=5E936C" alt="Documentation"></a>
    <a href="https://github.com/welpo/doteki/blob/main/COPYING">
        <img src="https://img.shields.io/github/license/welpo/doteki?style=flat-square&labelColor=202b2d&color=5E936C" alt="License"></a>
    <a href="https://doteki.org">
        <img src="https://img.shields.io/badge/powered_by-d%C5%8Dteki-0?style=flat-square&labelColor=202b2d&color=5E936C" alt="Powered by dōteki"></a>
</p>

<h4 align="center">
  <a href="https://doteki.org/docs">Documentation</a> |
  <a href="https://doteki.org">Website</a>
</h4>

**dōteki** makes it easy to add dynamic content to your GitHub profile leveraging customizable plugins managed through an intuitive TOML configuration file.

> dōteki (動的): dynamic.

## ✨ Main features

- **Easy to set up**: Uses a single TOML [configuration](https://doteki.org/docs/configuration) file and markers on your README.
- **Plugin system**: Extend functionality with a variety of [plugins](https://doteki.org/docs/category/plugins). Can't find what you need? [Create your own!](https://doteki.org/docs/developer-guide/plugin-standard)
- **Easy to automate**: Automatically update your profile with fresh content using the [GitHub Action](https://github.com/welpo/doteki-action).

## 📝 Documentation

Learn how to use **dōteki** from the [documentation](https://doteki.org/docs).

- [Initial setup](https://doteki.org/docs#initial-setup)
- [Configuration](https://doteki.org/docs/configuration)
- [Installation](https://doteki.org/docs/installation)
- [Plugins](https://doteki.org/docs/category/plugins)

## 👥 Contributing

Please do! Contributions are always welcome. We appreciate improvements to the documentation, development of new plugins, code cleanup, resolving issues, requesting or developing new functionality…

Take a look at our [Contributing Guidelines](/CONTRIBUTING.md) for more information on how to get started.

## 📄 License

This project is licensed under the GNU GPLv3 License or any later version.
